==> ember-bootstrap-form-1.0.0.tgz: package/addon/components/field-object.js <==
import Ember from 'ember';

const {Component, computed, observer} = Ember;

export default Component.extend({

    errorClass: 'has-error',
    successClass: 'has-success',

    errors: null,

    _message: null,

    _fieldValidationTriggered: false,

    _externalTriggered: observer('parent.triggeredValidation', function() {

        if (this.get('parent.triggeredValidation')) {
            this.set('_fieldValidationTriggered', true);
        }

    }),

    isTextArea: computed('type', function() {
        return Ember.isEqual(this.get('type'), 'textarea');

    }),

    isValid: computed('errors', function() {
        return Ember.isEmpty(this.get('errors'));

    }),

    isInvalid: computed.not('isValid'),

    validationStateClass: computed('isValid', 'willShowErrors', function() {

        if (!this.get('willShowErrors')) { return; }

        return this.get('isValid') ? this.get('successClass') : this.get('errorClass');

    }),

    label: computed('for', function() {
        return this.get('for').underscore().replace(/_/g, " ").capitalize();

    }),

    parent: computed.alias('parentView'),

    object: computed.alias('parent.for'),

    fieldId: computed('object', 'for', function() {
        return (Ember.guidFor(this.get('object'))) + "-input-" + (this.get('for'));

    }),

    setupBindings: function() {
        var fb = this.fieldsBinding,
            eb = this.errorsBinding;

        if (!Ember.isNone(fb)) {
            fb.disconnect(this);
        }

        if (!Ember.isNone(eb)) {
            eb.disconnect(this);
        }

        this.fieldsBinding = Ember.Binding.from("object." + this.get('for')).to('value');
        this.errorsBinding = Ember.Binding.from("object.errors." + this.get('for')).to('errors');

        this.fieldsBinding.connect(this);
        this.errorsBinding.connect(this);

    }.on('init').observes('for', 'object'),

    tearDownBindings: function() {
        
        var fb = this.fieldsBinding,
            eb = this.errorsBinding;

        if (fb) {
            fb.disconnect(this);
        }

        if (eb) {
            eb.disconnect(this);
        }

    }.on('willDestroyElement'),

    willShowErrors: computed.alias('_fieldValidationTriggered'),

    invalidMessage: computed.alias('_message'),

    errorsChanged: observer('errors', 'willShowErrors', function() {

        if (!this.get('willShowErrors')) { return; }

        var errors = this.get('errors');
        this.set('_message', !Ember.isEmpty(errors) ? errors.get('firstObject') : null);
    }),

    actions: {
        focusOutInput() {
            this.set('_fieldValidationTriggered', true);

        }
    }

});

==> ember-bootstrap-form-1.0.4.tgz: package/addon/components/field-object.js <==
import Ember from 'ember';

const {Component, computed, observer} = Ember;

export default Component.extend({

    errorClass: 'has-error',
    successClass: 'has-success',

    errors: null,
    
    _message: null,
    _fieldValidationTriggered: false,

    _externalTriggered: observer('parent.triggeredValidation', function() {

        if (this.get('parent.triggeredValidation')) {
            this.set('_fieldValidationTriggered', true);
        }

    }),

    isTextArea: computed.equal('type', 'textarea'),

    isValid: computed.empty('errors'),

    isInvalid: computed.not('isValid'),

    validationStateClass: computed('isValid', 'willShowErrors', function() {

        if (!this.get('willShowErrors')) { return; }

        return this.get('isValid') ? this.get('successClass') : this.get('errorClass');

    }),

    label: computed('for', function() {
        return this.get('for').underscore().replace(/_/g, " ").capitalize();

    }),

    parent: computed.alias('parentView'),

    object: computed.alias('parent.for'),

    fieldId: computed('object', 'for', function() {
        return (Ember.guidFor(this.get('object'))) + "-input-" + (this.get('for'));

    }),

    setupBindings: function() {
        var fb = this.fieldsBinding,
            eb = this.errorsBinding;

        if (!Ember.isNone(fb)) {
            fb.disconnect(this);
        }

        if (!Ember.isNone(eb)) {
            eb.disconnect(this);
        }

        this.fieldsBinding = Ember.Binding.from("object." + this.get('for')).to('value');
        this.errorsBinding = Ember.Binding.from("object.errors." + this.get('for')).to('errors');

        this.fieldsBinding.connect(this);
        this.errorsBinding.connect(this);

    }.on('init').observes('for', 'object'),

    tearDownBindings: function() {
        
        var fb = this.fieldsBinding,
            eb = this.errorsBinding;

        if (fb) {
            fb.disconnect(this);
        }

        if (eb) {
            eb.disconnect(this);
        }

    }.on('willDestroyElement'),

    willShowErrors: computed.alias('_fieldValidationTriggered'),

    invalidMessage: computed.alias('_message'),

    errorsChanged: observer('errors', 'willShowErrors', function() {

        if (!this.get('willShowErrors')) { return; }

        var errors = this.get('errors');
        this.set('_message', !Ember.isEmpty(errors) ? errors.get('firstObject') : null);
    }),

    actions: {
        focusOutInput() {
            this.set('_fieldValidationTriggered', true);

        }
    }

});
